<?php

/**
 * Kopano class.
 *
 * @category   apps
 * @package    kopano
 * @subpackage libraries
 * @author     ClearFoundation <developer@clearfoundation.com>
 * @copyright  2010-2012 Tim Burgess
 * @copyright  2011-2016 ClearFoundation
 * @license    http://www.gnu.org/copyleft/lgpl.html GNU Lesser General Public License version 3 or later
 * @link       http://www.clearfoundation.com/docs/developer/apps/kopano/
 */

///////////////////////////////////////////////////////////////////////////////
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
///////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////
// N A M E S P A C E
///////////////////////////////////////////////////////////////////////////////

namespace clearos\apps\kopano;

///////////////////////////////////////////////////////////////////////////////
// B O O T S T R A P
///////////////////////////////////////////////////////////////////////////////

$bootstrap = getenv('CLEAROS_BOOTSTRAP') ? getenv('CLEAROS_BOOTSTRAP') : '/usr/clearos/framework/shared';
require_once $bootstrap . '/bootstrap.php';

///////////////////////////////////////////////////////////////////////////////
// T R A N S L A T I O N S
///////////////////////////////////////////////////////////////////////////////

clearos_load_language('kopano');

///////////////////////////////////////////////////////////////////////////////
// D E P E N D E N C I E S
///////////////////////////////////////////////////////////////////////////////

use \clearos\apps\base\Daemon as Daemon;
use \clearos\apps\base\Engine as Engine;
use \clearos\apps\base\Software as Software;

clearos_load_library('base/Daemon');
clearos_load_library('base/Engine');
clearos_load_library('base/Software');

///////////////////////////////////////////////////////////////////////////////
// C L A S S
///////////////////////////////////////////////////////////////////////////////

/**
 * Kopano class.
 *
 * @category   apps
 * @package    kopano
 * @subpackage libraries
 * @author     ClearFoundation <developer@clearfoundation.com>
 * @copyright  2010-2012 Tim Burgess
 * @copyright  2011-2016 ClearFoundation
 * @license    http://www.gnu.org/copyleft/lgpl.html GNU Lesser General Public License version 3 or later
 * @link       http://www.clearfoundation.com/docs/developer/apps/kopano/
 */

class Kopano extends Engine
{
    ///////////////////////////////////////////////////////////////////////////////
    // V A R I A B L E S
    ///////////////////////////////////////////////////////////////////////////////

    protected $services = array();

    ///////////////////////////////////////////////////////////////////////////////
    // M E T H O D S
    ///////////////////////////////////////////////////////////////////////////////

    /**
     * Kopano constructor.
     */

    function __construct()
    {
        clearos_profile(__METHOD__, __LINE__);
    }

    /**
     * Returns list of Kopano daemon services.
     *
     * @return array list of Kopano daemon services.
     * @throws Engine_Exception
     */

    public function get_services()
    {
        clearos_profile(__METHOD__, __LINE__);

        $services = array(
            'httpd' => lang('kopano_web_server'),
            'kopano-dagent' => lang('kopano_kopano_delivery_agent'),
            'kopano-gateway' => lang('kopano_kopano_pop_imap_gateway'),
            'kopano-ical' => lang('kopano_kopano_ical_gateway'),
            'kopano-monitor' => lang('kopano_kopano_quota_monitor'),
            'kopano-server' => lang('kopano_kopano_server'),
            'kopano-spooler' => lang('kopano_kopano_spooler'),
            'kopano-search' => lang('kopano_kopano_search_indexer')
        );

        $software = new Software('kopano-dsd');
        if ($software->is_installed())
            $services['kopano-dsd'] = lang('kopano_kopano_dsd');


        $software = new Software('kopano-webmeetings');
        if ($software->is_installed()) {
            $services['kopano-webmeetings'] = lang('kopano_kopano_webmeetings');
            $software = new Software('kopano-presence');
            if ($software->is_installed())
                $services['kopano-presence'] = lang('kopano_kopano_presence');
        }

        return $services;
    }

    /**
     * Returns information on Kopano daemon services.
     *
     * @return array information on Kopano daemon services.
     * @throws Engine_Exception
     */

    public function get_services_info()
    {
        clearos_profile(__METHOD__, __LINE__);

        $services_info = array();

        foreach ($this->get_services() as $daemon_name => $description) {
            $daemon = new Daemon($daemon_name);

            $services_info[$daemon_name]['description'] = $description;
            $services_info[$daemon_name]['running_state'] = $daemon->get_running_state();
        }

        return $services_info;
    }
}
