<?php

/**
 * Kopano Basic for ClearOS backup controller.
 *
 * @category   apps
 * @package    kopano-basic
 * @subpackage controllers
 * @author     ClearCenter <developer@clearcenter.com>
 * @copyright  2015 ClearCenter
 * @license    http://www.clearcenter.com/app_license ClearCenter license
 * @link       http://www.clearcenter.com/support/documentation/clearos/kopano_basic/
 */

///////////////////////////////////////////////////////////////////////////////
// B O O T S T R A P
///////////////////////////////////////////////////////////////////////////////

$bootstrap = getenv('CLEAROS_BOOTSTRAP') ? getenv('CLEAROS_BOOTSTRAP') : '/usr/clearos/framework/shared';
require_once $bootstrap . '/bootstrap.php';

///////////////////////////////////////////////////////////////////////////////
// D E P E N D E N C I E S
///////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////
// C L A S S
///////////////////////////////////////////////////////////////////////////////

/**
 * Kopano Basic for ClearOS backup controller.
 *
 * @category   apps
 * @package    kopano-basic
 * @subpackage controllers
 * @author     ClearCenter <developer@clearcenter.com>
 * @copyright  2015 ClearCenter
 * @license    http://www.clearcenter.com/app_license ClearCenter license
 * @link       http://www.clearcenter.com/support/documentation/clearos/kopano_basic/
 */

class Backup extends ClearOS_Controller
{

    /**
     * Kopano small business backup controller
     *
     * @return view
     */

    function index()
    {
        $this->_view_edit('view');
    }

    /**
     * Kopano small business backup edit controller
     *
     * @return view
     */

    function edit()
    {
        $this->_view_edit('edit');
    }

    /**
     * Common view/edit form
     *
     * @param string $mode form mode
     *
     * @return view
     */

    function _view_edit($mode)
    {

        // Load libraries
        //---------------

        $this->lang->load('kopano_basic');
        $this->load->library('kopano_basic/Kopano_Basic');

        // Set validation rules
        //---------------------

        $this->form_validation->set_policy('frequency', 'kopano_basic/Kopano_Basic', 'validate_backup_frequency', TRUE);
        $this->form_validation->set_policy('destination', 'kopano_basic/Kopano_Basic', 'validate_backup_destination', TRUE);

        // Handle form submit
        //-------------------

        $form_ok = $this->form_validation->run();

        if (($this->input->post('submit') && $form_ok)) {
            try {
                $this->kopano_basic->set_backup_frequency($this->input->post('frequency'));
                $this->kopano_basic->set_backup_destination_folder($this->input->post('destination'));
                $this->page->set_message(lang('kopano_basic_backup_settings_updated'), 'info');
                redirect('/kopano_basic');
            } catch (Exception $e) {
                $this->page->view_exception($e);
                return;
            }
        }

        $data['mode'] = $mode;

        // Load view data
        //---------------

        try {
            $data['frequency'] = $this->kopano_basic->get_backup_frequency();
            $data['destination'] = $this->kopano_basic->get_backup_destination_folder();
            $data['frequency_options'] = $this->kopano_basic->get_backup_frequency_options();
            $data['destination_options'] = $this->kopano_basic->get_backup_destination_folder_options();
        } catch (Exception $e) {
            $this->page->view_exception($e);
            return;
        }

        // Load views
        //-----------

        $this->page->view_form('kopano_basic/backup', $data, lang('kopano_basic_licenses'));
    }
}
